==> ec2-1.0.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/services/ec2/CfnDHCPOptionsProps.java <==
package software.amazon.awscdk.services.ec2;

/**
 * Properties for defining a `AWS::EC2::DHCPOptions`.
 * 
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-dhcp-options.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.14.0 (build a586a1a)", date = "2019-07-11T14:13:21.570Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnDHCPOptionsProps extends software.amazon.jsii.JsiiSerializable {
    /**
     * `AWS::EC2::DHCPOptions.DomainName`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-dhcp-options.html#cfn-ec2-dhcpoptions-domainname
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    java.lang.String getDomainName();
    /**
     * `AWS::EC2::DHCPOptions.DomainNameServers`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-dhcp-options.html#cfn-ec2-dhcpoptions-domainnameservers
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    java.util.List<java.lang.String> getDomainNameServers();
    /**
     * `AWS::EC2::DHCPOptions.NetbiosNameServers`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-dhcp-options.html#cfn-ec2-dhcpoptions-netbiosnameservers
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    java.util.List<java.lang.String> getNetbiosNameServers();
    /**
     * `AWS::EC2::DHCPOptions.NetbiosNodeType`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-dhcp-options.html#cfn-ec2-dhcpoptions-netbiosnodetype
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    java.lang.Number getNetbiosNodeType();
    /**
     * `AWS::EC2::DHCPOptions.NtpServers`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-dhcp-options.html#cfn-ec2-dhcpoptions-ntpservers
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    java.util.List<java.lang.String> getNtpServers();
    /**
     * `AWS::EC2::DHCPOptions.Tags`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-dhcp-options.html#cfn-ec2-dhcpoptions-tags
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    java.util.List<software.amazon.awscdk.core.CfnTag> getTags();

    /**
     * @return a {@link Builder} of {@link CfnDHCPOptionsProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }

    /**
     * A builder for {@link CfnDHCPOptionsProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    final class Builder {
        @javax.annotation.Nullable
        private java.lang.String _domainName;
        @javax.annotation.Nullable
        private java.util.List<java.lang.String> _domainNameServers;
        @javax.annotation.Nullable
        private java.util.List<java.lang.String> _netbiosNameServers;
        @javax.annotation.Nullable
        private java.lang.Number _netbiosNodeType;
        @javax.annotation.Nullable
        private java.util.List<java.lang.String> _ntpServers;
        @javax.annotation.Nullable
        private java.util.List<software.amazon.awscdk.core.CfnTag> _tags;

        /**
         * Sets the value of DomainName
         * @param value `AWS::EC2::DHCPOptions.DomainName`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder withDomainName(@javax.annotation.Nullable final java.lang.String value) {
            this._domainName = value;
            return this;
        }
        /**
         * Sets the value of DomainNameServers
         * @param value `AWS::EC2::DHCPOptions.DomainNameServers`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder withDomainNameServers(@javax.annotation.Nullable final java.util.List<java.lang.String> value) {
            this._domainNameServers = value;
            return this;
        }
        /**
         * Sets the value of NetbiosNameServers
         * @param value `AWS::EC2::DHCPOptions.NetbiosNameServers`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder withNetbiosNameServers(@javax.annotation.Nullable final java.util.List<java.lang.String> value) {
            this._netbiosNameServers = value;
            return this;
        }
        /**
         * Sets the value of NetbiosNodeType
         * @param value `AWS::EC2::DHCPOptions.NetbiosNodeType`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder withNetbiosNodeType(@javax.annotation.Nullable final java.lang.Number value) {
            this._netbiosNodeType = value;
            return this;
        }
        /**
         * Sets the value of NtpServers
         * @param value `AWS::EC2::DHCPOptions.NtpServers`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder withNtpServers(@javax.annotation.Nullable final java.util.List<java.lang.String> value) {
            this._ntpServers = value;
            return this;
        }
        /**
         * Sets the value of Tags
         * @param value `AWS::EC2::DHCPOptions.Tags`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder withTags(@javax.annotation.Nullable final java.util.List<software.amazon.awscdk.core.CfnTag> value) {
            this._tags = value;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnDHCPOptionsProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public CfnDHCPOptionsProps build() {
            return new CfnDHCPOptionsProps() {
                @javax.annotation.Nullable
                private final java.lang.String $domainName = _domainName;
                @javax.annotation.Nullable
                private final java.util.List<java.lang.String> $domainNameServers = _domainNameServers;
                @javax.annotation.Nullable
                private final java.util.List<java.lang.String> $netbiosNameServers = _netbiosNameServers;
                @javax.annotation.Nullable
                private final java.lang.Number $netbiosNodeType = _netbiosNodeType;
                @javax.annotation.Nullable
                private final java.util.List<java.lang.String> $ntpServers = _ntpServers;
                @javax.annotation.Nullable
                private final java.util.List<software.amazon.awscdk.core.CfnTag> $tags = _tags;

                @Override
                public java.lang.String getDomainName() {
                    return this.$domainName;
                }

                @Override
                public java.util.List<java.lang.String> getDomainNameServers() {
                    return this.$domainNameServers;
                }

                @Override
                public java.util.List<java.lang.String> getNetbiosNameServers() {
                    return this.$netbiosNameServers;
                }

                @Override
                public java.lang.Number getNetbiosNodeType() {
                    return this.$netbiosNodeType;
                }

                @Override
                public java.util.List<java.lang.String> getNtpServers() {
                    return this.$ntpServers;
                }

                @Override
                public java.util.List<software.amazon.awscdk.core.CfnTag> getTags() {
                    return this.$tags;
                }

                public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
                    com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
                    com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
                    if (this.getDomainName() != null) {
                        obj.set("domainName", om.valueToTree(this.getDomainName()));
                    }
                    if (this.getDomainNameServers() != null) {
                        obj.set("domainNameServers", om.valueToTree(this.getDomainNameServers()));
                    }
                    if (this.getNetbiosNameServers() != null) {
                        obj.set("netbiosNameServers", om.valueToTree(this.getNetbiosNameServers()));
                    }
                    if (this.getNetbiosNodeType() != null) {
                        obj.set("netbiosNodeType", om.valueToTree(this.getNetbiosNodeType()));
                    }
                    if (this.getNtpServers() != null) {
                        obj.set("ntpServers", om.valueToTree(this.getNtpServers()));
                    }
                    if (this.getTags() != null) {
                        obj.set("tags", om.valueToTree(this.getTags()));
                    }
                    return obj;
                }

            };
        }
    }

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.ec2.CfnDHCPOptionsProps {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
            super(mode);
        }

        /**
         * `AWS::EC2::DHCPOptions.DomainName`.
         * 
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-dhcp-options.html#cfn-ec2-dhcpoptions-domainname
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @javax.annotation.Nullable
        public java.lang.String getDomainName() {
            return this.jsiiGet("domainName", java.lang.String.class);
        }

        /**
         * `AWS::EC2::DHCPOptions.DomainNameServers`.
         * 
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-dhcp-options.html#cfn-ec2-dhcpoptions-domainnameservers
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @javax.annotation.Nullable
        public java.util.List<java.lang.String> getDomainNameServers() {
            return this.jsiiGet("domainNameServers", java.util.List.class);
        }

        /**
         * `AWS::EC2::DHCPOptions.NetbiosNameServers`.
         * 
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-dhcp-options.html#cfn-ec2-dhcpoptions-netbiosnameservers
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @javax.annotation.Nullable
        public java.util.List<java.lang.String> getNetbiosNameServers() {
            return this.jsiiGet("netbiosNameServers", java.util.List.class);
        }

        /**
         * `AWS::EC2::DHCPOptions.NetbiosNodeType`.
         * 
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-dhcp-options.html#cfn-ec2-dhcpoptions-netbiosnodetype
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @javax.annotation.Nullable
        public java.lang.Number getNetbiosNodeType() {
            return this.jsiiGet("netbiosNodeType", java.lang.Number.class);
        }

        /**
         * `AWS::EC2::DHCPOptions.NtpServers`.
         * 
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-dhcp-options.html#cfn-ec2-dhcpoptions-ntpservers
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @javax.annotation.Nullable
        public java.util.List<java.lang.String> getNtpServers() {
            return this.jsiiGet("ntpServers", java.util.List.class);
        }

        /**
         * `AWS::EC2::DHCPOptions.Tags`.
         * 
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-dhcp-options.html#cfn-ec2-dhcpoptions-tags
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @javax.annotation.Nullable
        public java.util.List<software.amazon.awscdk.core.CfnTag> getTags() {
            return this.jsiiGet("tags", java.util.List.class);
        }
    }
}

==> ec2-1.1.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/services/ec2/CfnDHCPOptionsProps.java <==
package software.amazon.awscdk.services.ec2;

/**
 * Properties for defining a `AWS::EC2::DHCPOptions`.
 * 
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-dhcp-options.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.14.2 (build e881f16)", date = "2019-07-19T19:06:47.491Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
public interface CfnDHCPOptionsProps extends software.amazon.jsii.JsiiSerializable {
    /**
     * `AWS::EC2::DHCPOptions.DomainName`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-dhcp-options.html#cfn-ec2-dhcpoptions-domainname
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.String getDomainName();
    /**
     * `AWS::EC2::DHCPOptions.DomainNameServers`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-dhcp-options.html#cfn-ec2-dhcpoptions-domainnameservers
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.util.List<java.lang.String> getDomainNameServers();
    /**
     * `AWS::EC2::DHCPOptions.NetbiosNameServers`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-dhcp-options.html#cfn-ec2-dhcpoptions-netbiosnameservers
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.util.List<java.lang.String> getNetbiosNameServers();
    /**
     * `AWS::EC2::DHCPOptions.NetbiosNodeType`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-dhcp-options.html#cfn-ec2-dhcpoptions-netbiosnodetype
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.Number getNetbiosNodeType();
    /**
     * `AWS::EC2::DHCPOptions.NtpServers`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-dhcp-options.html#cfn-ec2-dhcpoptions-ntpservers
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.util.List<java.lang.String> getNtpServers();
    /**
     * `AWS::EC2::DHCPOptions.Tags`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-dhcp-options.html#cfn-ec2-dhcpoptions-tags
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.util.List<software.amazon.awscdk.core.CfnTag> getTags();

    /**
     * @return a {@link Builder} of {@link CfnDHCPOptionsProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    static Builder builder() {
        return new Builder();
    }

    /**
     * A builder for {@link CfnDHCPOptionsProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    final class Builder {
        @javax.annotation.Nullable
        private java.lang.String _domainName;
        @javax.annotation.Nullable
        private java.util.List<java.lang.String> _domainNameServers;
        @javax.annotation.Nullable
        private java.util.List<java.lang.String> _netbiosNameServers;
        @javax.annotation.Nullable
        private java.lang.Number _netbiosNodeType;
        @javax.annotation.Nullable
        private java.util.List<java.lang.String> _ntpServers;
        @javax.annotation.Nullable
        private java.util.List<software.amazon.awscdk.core.CfnTag> _tags;

        /**
         * Sets the value of DomainName
         * @param value `AWS::EC2::DHCPOptions.DomainName`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder withDomainName(@javax.annotation.Nullable final java.lang.String value) {
            this._domainName = value;
            return this;
        }
        /**
         * Sets the value of DomainNameServers
         * @param value `AWS::EC2::DHCPOptions.DomainNameServers`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder withDomainNameServers(@javax.annotation.Nullable final java.util.List<java.lang.String> value) {
            this._domainNameServers = value;
            return this;
        }
        /**
         * Sets the value of NetbiosNameServers
         * @param value `AWS::EC2::DHCPOptions.NetbiosNameServers`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder withNetbiosNameServers(@javax.annotation.Nullable final java.util.List<java.lang.String> value) {
            this._netbiosNameServers = value;
            return this;
        }
        /**
         * Sets the value of NetbiosNodeType
         * @param value `AWS::EC2::DHCPOptions.NetbiosNodeType`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder withNetbiosNodeType(@javax.annotation.Nullable final java.lang.Number value) {
            this._netbiosNodeType = value;
            return this;
        }
        /**
         * Sets the value of NtpServers
         * @param value `AWS::EC2::DHCPOptions.NtpServers`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder withNtpServers(@javax.annotation.Nullable final java.util.List<java.lang.String> value) {
            this._ntpServers = value;
            return this;
        }
        /**
         * Sets the value of Tags
         * @param value `AWS::EC2::DHCPOptions.Tags`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder withTags(@javax.annotation.Nullable final java.util.List<software.amazon.awscdk.core.CfnTag> value) {
            this._tags = value;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnDHCPOptionsProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public CfnDHCPOptionsProps build() {
            return new CfnDHCPOptionsProps() {
                @javax.annotation.Nullable
                private final java.lang.String $domainName = _domainName;
                @javax.annotation.Nullable
                private final java.util.List<java.lang.String> $domainNameServers = _domainNameServers;
                @javax.annotation.Nullable
                private final java.util.List<java.lang.String> $netbiosNameServers = _netbiosNameServers;
                @javax.annotation.Nullable
                private final java.lang.Number $netbiosNodeType = _netbiosNodeType;
                @javax.annotation.Nullable
                private final java.util.List<java.lang.String> $ntpServers = _ntpServers;
                @javax.annotation.Nullable
                private final java.util.List<software.amazon.awscdk.core.CfnTag> $tags = _tags;

                @Override
                public java.lang.String getDomainName() {
                    return this.$domainName;
                }

                @Override
                public java.util.List<java.lang.String> getDomainNameServers() {
                    return this.$domainNameServers;
                }

                @Override
                public java.util.List<java.lang.String> getNetbiosNameServers() {
                    return this.$netbiosNameServers;
                }

                @Override
                public java.lang.Number getNetbiosNodeType() {
                    return this.$netbiosNodeType;
                }

                @Override
                public java.util.List<java.lang.String> getNtpServers() {
                    return this.$ntpServers;
                }

                @Override
                public java.util.List<software.amazon.awscdk.core.CfnTag> getTags() {
                    return this.$tags;
                }

                public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
                    com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
                    com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
                    if (this.getDomainName() != null) {
                        obj.set("domainName", om.valueToTree(this.getDomainName()));
                    }
                    if (this.getDomainNameServers() != null) {
                        obj.set("domainNameServers", om.valueToTree(this.getDomainNameServers()));
                    }
                    if (this.getNetbiosNameServers() != null) {
                        obj.set("netbiosNameServers", om.valueToTree(this.getNetbiosNameServers()));
                    }
                    if (this.getNetbiosNodeType() != null) {
                        obj.set("netbiosNodeType", om.valueToTree(this.getNetbiosNodeType()));
                    }
                    if (this.getNtpServers() != null) {
                        obj.set("ntpServers", om.valueToTree(this.getNtpServers()));
                    }
                    if (this.getTags() != null) {
                        obj.set("tags", om.valueToTree(this.getTags()));
                    }
                    return obj;
                }

            };
        }
    }

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.ec2.CfnDHCPOptionsProps {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
            super(mode);
        }

        /**
         * `AWS::EC2::DHCPOptions.DomainName`.
         * 
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-dhcp-options.html#cfn-ec2-dhcpoptions-domainname
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        @javax.annotation.Nullable
        public java.lang.String getDomainName() {
            return this.jsiiGet("domainName", java.lang.String.class);
        }

        /**
         * `AWS::EC2::DHCPOptions.DomainNameServers`.
         * 
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-dhcp-options.html#cfn-ec2-dhcpoptions-domainnameservers
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        @javax.annotation.Nullable
        public java.util.List<java.lang.String> getDomainNameServers() {
            return this.jsiiGet("domainNameServers", java.util.List.class);
        }

        /**
         * `AWS::EC2::DHCPOptions.NetbiosNameServers`.
         * 
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-dhcp-options.html#cfn-ec2-dhcpoptions-netbiosnameservers
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        @javax.annotation.Nullable
        public java.util.List<java.lang.String> getNetbiosNameServers() {
            return this.jsiiGet("netbiosNameServers", java.util.List.class);
        }

        /**
         * `AWS::EC2::DHCPOptions.NetbiosNodeType`.
         * 
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-dhcp-options.html#cfn-ec2-dhcpoptions-netbiosnodetype
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        @javax.annotation.Nullable
        public java.lang.Number getNetbiosNodeType() {
            return this.jsiiGet("netbiosNodeType", java.lang.Number.class);
        }

        /**
         * `AWS::EC2::DHCPOptions.NtpServers`.
         * 
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-dhcp-options.html#cfn-ec2-dhcpoptions-ntpservers
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        @javax.annotation.Nullable
        public java.util.List<java.lang.String> getNtpServers() {
            return this.jsiiGet("ntpServers", java.util.List.class);
        }

        /**
         * `AWS::EC2::DHCPOptions.Tags`.
         * 
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-dhcp-options.html#cfn-ec2-dhcpoptions-tags
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        @javax.annotation.Nullable
        public java.util.List<software.amazon.awscdk.core.CfnTag> getTags() {
            return this.jsiiGet("tags", java.util.List.class);
        }
    }
}
